@@ -1,6 +1,6 @@
 <?php
 
-if (substr($messaggio,0,4) != "var_") {
+if (substr((string) $messaggio,0,4) != "var_") {
 switch ($messaggio) {
 
 # translate YES and NO in upper case
@@ -57,8 +57,6 @@ case "Mostrare la caparra se presente?":  	$messaggio = "Laat deposito zien als
 case "Mostrare quali sono i giorni pieni all'interno dei periodi dove non c'è più disponibilità?":	$messaggio = "Laat zien welke dagen vol zijn binnen de periode waar geen beschikbaarheid meer is?"; break;
 case "Mostrare la form di richiesta prenotazione?":	$messaggio = "Toon het aanvraag reserveringsformulier?"; break;
 case "Indirizzo email a cui inviare le richieste di prenotazione":	$messaggio = "Emailadres waar het verzoek tot reservering naar toe moet"; break;
-case "Mascherare la provenienza dell'email sull'envelope?":	$messaggio = "Maskeer de afzender op het emailbericht?"; break;
-case "provare a cambiare se non si riescono a spedire le email":	$messaggio = "probeer dit te wijzigen als U geen email kunt zenden"; break;
 case "Controlla la disponibilità":  		$messaggio = "Controleer beschikbaarheid"; break;
 case "dal":  					$messaggio = "van"; break;
 case "al":  					$messaggio = "tot"; break;
@@ -269,6 +267,7 @@ case "Pagine importate":  			$messaggio = "Pages imported"; break;
 case "con i servizi opzionali selezionati":  	$messaggio = "with selected optional services"; break;
 case "Utilizzare le personalizzazioni (tipi di persone, liste di nazioni, regioni, ecc.) dell'utente":	$messaggio = "Use customizations (people types, lists of nations, regions, etc.) from user"; break;
 case "Url del file css per la modalità frame":	$messaggio = "Url of css file for framed mode"; break;
+case "Url del file javascript per la modalità frame":	$messaggio = "Url of javascript file for framed mode"; break;
 case "Utilizza per l'aspetto della pagina":  	$messaggio = "Use for page appearance"; break;
 case "html personalizzato":  			$messaggio = "custom html"; break;
 case "il tema chiamato":  			$messaggio = "the theme called"; break;
@@ -300,6 +299,7 @@ case "aggiunto al commento":  			$messaggio = "added to comment"; break;
 case "aggiunto al campo":  			$messaggio = "added to field"; break;
 case "del cliente":  				$messaggio = "in client data"; break;
 case "URL file css":  				$messaggio = "URL of css file"; break;
+case "URL file javascript":  			$messaggio = "URL of javascript file"; break;
 case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "there are rates without assignment rule n. 2"; break;
 case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
 case "Partita iva":  				$messaggio = "VAT number"; break;
@@ -330,9 +330,13 @@ case "Raggruppamento":  			$messaggio = "Grouping"; break;
 case "Valuta della caparra":  			$messaggio = "Deposit currency"; break;
 case "Seconda email":  				$messaggio = "Second email"; break;
 case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
-case "Url del file javascript per la modalità frame":	$messaggio = "Url of javascript file for framed mode"; break;
-case "URL file javascript":  			$messaggio = "URL of javascript file"; break;
 case "non deve contenere \"php\" e deve terminare con \".js\"":	$messaggio = "must not contain \"php\" and must end with \".js\""; break;
+case "notte":  					$messaggio = "night"; break;
+case "notti":  					$messaggio = "nights"; break;
+case "cambia date":  				$messaggio = "change dates"; break;
+case "Per questa tariffa si deve inserire un minimo di":	$messaggio = "For this rate you have to insert at least"; break;
+case "Secondo cognome":  			$messaggio = "Second surname"; break;
+case "2° cognome":  				$messaggio = "2nd surname"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -340,7 +344,7 @@ case "":  		$messaggio = ""; break;
 case "mdl_disponibilita":  			$messaggio = "beschikbaarheids_mlp"; break;
 
 } # fine switch ($messaggio)
-} # fine if (substr($messaggio,0,4) != "var_")
+} # fine if (substr((string) $messaggio,0,4) != "var_")
 
 
 else {
@@ -383,7 +387,6 @@ case "var_mostra_frase_alternativa_regola1":  	$messaggio = "var_show_alternativ
 case "var_mostra_caparra":  			$messaggio = "var_show_deposit"; break;
 case "var_mostra_richiesta_via_mail":  		$messaggio = "var_show_request_by_mail"; break;
 case "var_indirizzo_email":  			$messaggio = "var_email_address"; break;
-case "var_maschera_email":  			$messaggio = "var_masquerade_email_envelope"; break;
 case "var_mostra_giorni_pieni":  		$messaggio = "var_show_full_days"; break;
 case "var_mostra_bottone_paypal":  		$messaggio = "var_show_paypal_button"; break;
 case "var_nome_modello_paypal":  		$messaggio = "var_paypal_template_name"; break;
@@ -404,6 +407,7 @@ case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_active_calen
 case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_selected_calendar_date"; break;
 case "var_stile_tabella_prenotazione":  	$messaggio = "var_reservation_table_style"; break;
 case "var_file_css_frame":  			$messaggio = "var_framed_css_file"; break;
+case "var_file_js_frame":  			$messaggio = "var_framed_js_file"; break;
 case "var_apri_nuova_finestra_da_frame":  	$messaggio = "var_open_new_window_from_frame"; break;
 case "var_larghezza_finestra_da_frame":  	$messaggio = "var_window_from_frame_width"; break;
 case "var_altezza_finestra_da_frame":  		$messaggio = "var_window_from_frame_height"; break;
@@ -616,12 +620,17 @@ case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positio
 case "var_fr_Codice_promozionale":  		$messaggio = "var_phr_Promotional_code"; break;
 case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_phr_Promotional_code_applied"; break;
 case "var_fr_Si_deve_inserire_almeno_una_persona_che_possa_ecc":	$messaggio = "var_phr_You_must_include_at_least_one_person_who_can_etc"; break;
+case "var_fr_notte":  				$messaggio = "var_phr_night"; break;
+case "var_fr_notti":  				$messaggio = "var_phr_nights"; break;
+case "var_fr_cambia_date":  			$messaggio = "var_phr_change_dates"; break;
+case "var_fr_Per_questa_tariffa_si_deve_inserire_un_minimo_di":	$messaggio = "var_phr_For_this_rate_you_have_to_insert_at_least"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
-case "var_file_js_frame":  			$messaggio = "var_framed_js_file"; break;
+case "var_chiedi_cognome2":  			$messaggio = "var_ask_surname2"; break;
+case "var_fr_Secondo_cognome":  		$messaggio = "var_phr_Second_surname"; break;
 } # fine switch ($messaggio)
-} # fine else if (substr($messaggio,0,4) != "var_")
+} # fine else if (substr((string) $messaggio,0,4) != "var_")
 
 
 
-?>
\ No newline at end of file
+?>
